
// policy accountability paper 1
// regresses treatment variables and control for issue position, issue strength, and self-placed party ID on outcome variables
set more off
clear
cd "" // SET DIRECTORY 
use candidate_vignette_final_dataset.dta


// generate dummy variables for seeing each issue area
gen Guns_inserts = 0 
replace Guns_inserts = 1 if three_issues == "G Ab T" | three_issues == "G I Ab" | three_issues == "G I SS" | three_issues == "G I T" |  three_issues == "G SS Ab" | three_issues == "G SS T" | three_issues == "G W Ab" | ///
three_issues == "G W I" | three_issues == "G W SS" | three_issues == "G W T" 
label var Guns_inserts "Guns issue area displayed"

gen Abortion_inserts = 0 
replace Abortion_inserts = 1 if three_issues == "G Ab T" | three_issues == "G I Ab" | three_issues == "G SS Ab " | three_issues == "G W Ab " |  three_issues == "I Ab T" | three_issues == "I SS Ab" | three_issues == "SS Ab T" | ///
three_issues == "W Ab T" | three_issues == "W I Ab" | three_issues == "W SS Ab" 
label var Abortion_inserts "Abortion issue area displayed"

gen Taxes_inserts = 0 
replace Taxes_inserts = 1 if three_issues == " G I Ab" | three_issues == "G I SS" | three_issues == "G I T" | three_issues == "G W I"  |  three_issues == "I Ab T" | three_issues == "I SS T" | three_issues == "SS Ab T" | ///
three_issues == "W Ab T" | three_issues == "W I T" | three_issues == "W SS T" 
label var Taxes_inserts "Taxes issue area displayed"

gen ISIS_inserts = 0 
replace ISIS_inserts = 1 if three_issues == "G I Ab" | three_issues == "G I SS" | three_issues == "G I T" | three_issues == "G W I"  |  three_issues == "I Ab T" | three_issues == "I SS Ab" | three_issues == "I SS T" | ///
three_issues == "W I Ab" | three_issues == "W I SS" | three_issues == "W I T" 
label var ISIS_inserts "ISIS issue area displayed"

gen SocialSecurity_inserts = 0 
replace SocialSecurity_inserts = 1 if three_issues == "G I SS" | three_issues == "G SS Ab" | three_issues == "G SS T" | three_issues == "G W SS"  |  three_issues == "I SS Ab" | three_issues == "I SS T" | three_issues == "SS Ab T" | ///
three_issues == "W I SS" | three_issues == "W SS Ab" | three_issues == "W SS T" 
label var SocialSecurity_inserts "Social Security issue area displayed"

gen Welfare_inserts = 0 
replace Welfare_inserts = 1 if three_issues == "G W Ab" | three_issues == "G W I" | three_issues == "G W SS" | three_issues == "G W T"  |  three_issues == "W Ab T" | three_issues == "W I Ab" | three_issues == "W I SS" | ///
three_issues == "W I T" | three_issues == "W SS Ab" | three_issues == "W SS T" 
label var Welfare_inserts "Welfare issue area displayed"

//generate dummy variable for seeing liberal (conservative) vs. somewhat liberal (conservative) issue positions (1=lib, 0=somewhat lib)
gen guns_lib_d = 0
replace guns_lib_d = 1 if Guns_insert_aligned_dem_main == "I support “no-issue” concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun." & group == "Group_1" & pid_candidate == "Dem" 
replace guns_lib_d = 1 if Guns_insert_aligned_dem_main == "I support “no-issue” concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun." & group == "Group_2" & pid_candidate == "Dem" 
replace guns_lib_d = 1 if Guns_insert_aligned_dem_main == "I support “no-issue” concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun." & group == "Group_3" & pid_candidate == "Dem" 
replace guns_lib_d = 1 if Guns_insert_aligned_dem_main == "I support “no-issue” concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun." & group == "Group_4" & pid_candidate == "Dem"  
label var guns_lib_d "Guns: liberal position"

gen taxes_lib_d = 0
replace taxes_lib_d = 1 if Taxes_insert_aligned_dem_main == "I support raising the top marginal tax rate to 60% for those making more than $1,000,000." & group == "Group_1" 
replace taxes_lib_d = 1 if Taxes_insert_aligned_dem_main == "I support raising the top marginal tax rate to 60% for those making more than $1,000,000." & group == "Group_2" & pid_candidate == "Dem"  
replace taxes_lib_d = 1 if Taxes_insert_aligned_dem_main == "I support raising the top marginal tax rate to 60% for those making more than $1,000,000." & group == "Group_3" & pid_candidate == "Dem"  
replace taxes_lib_d = 1 if Taxes_insert_aligned_dem_main == "I support raising the top marginal tax rate to 60% for those making more than $1,000,000." & group == "Group_4" & pid_candidate == "Dem"  
label var taxes_lib_d "Taxes: liberal position"

gen SS_lib_d = 0
replace SS_lib_d = 1 if SS_insert_aligned_dem_main == "To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes." & group == "Group_1" & pid_candidate == "Dem"  
replace SS_lib_d = 1 if SS_insert_aligned_dem_main == "To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes." & group == "Group_2" & pid_candidate == "Dem"  
replace SS_lib_d = 1 if SS_insert_aligned_dem_main == "To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes." & group == "Group_3" & pid_candidate == "Dem"  
replace SS_lib_d = 1 if SS_insert_aligned_dem_main == "To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes." & group == "Group_4" & pid_candidate == "Dem"  
label var SS_lib_d "Social Security: liberal position"

gen Abort_lib_d = 0
replace Abort_lib_d = 1 if Abort_insert_aligned_dem_main == "I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent." & group == "Group_1" & pid_candidate == "Dem"  
replace Abort_lib_d = 1 if Abort_insert_aligned_dem_main == "I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent." & group == "Group_2" & pid_candidate == "Dem"  
replace Abort_lib_d = 1 if Abort_insert_aligned_dem_main == "I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent." & group == "Group_3" & pid_candidate == "Dem"  
replace Abort_lib_d = 1 if Abort_insert_aligned_dem_main == "I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent." & group == "Group_4" & pid_candidate == "Dem"  
label var Abort_lib_d "Abortion: liberal position"

gen Welfare_lib_d = 0
replace Welfare_lib_d = 1 if Welfare_insert_aligned_dem_main == "I support raising the lifetime cap from 5 years to 9 years." & group == "Group_1" & pid_candidate == "Dem"  
replace Welfare_lib_d = 1 if Welfare_insert_aligned_dem_main == "I support raising the lifetime cap from 5 years to 9 years." & group == "Group_2" & pid_candidate == "Dem"  
replace Welfare_lib_d = 1 if Welfare_insert_aligned_dem_main == "I support raising the lifetime cap from 5 years to 9 years." & group == "Group_3" & pid_candidate == "Dem"  
replace Welfare_lib_d = 1 if Welfare_insert_aligned_dem_main == "I support raising the lifetime cap from 5 years to 9 years." & group == "Group_4" & pid_candidate == "Dem"  
label var Welfare_lib_d "Welfare: liberal position"

gen ISIS_lib_d = 0
replace ISIS_lib_d = 1 if ISIS_insert_aligned_dem_main == "I do not support sending additional air power or any ground troops to Syria and Iraq." & group == "Group_1" & pid_candidate == "Dem"  
replace ISIS_lib_d = 1 if ISIS_insert_aligned_dem_main == "I do not support sending additional air power or any ground troops to Syria and Iraq." & group == "Group_2" & pid_candidate == "Dem"  
replace ISIS_lib_d = 1 if ISIS_insert_aligned_dem_main == "I do not support sending additional air power or any ground troops to Syria and Iraq." & group == "Group_3" & pid_candidate == "Dem"  
replace ISIS_lib_d = 1 if ISIS_insert_aligned_dem_main == "I do not support sending additional air power or any ground troops to Syria and Iraq." & group == "Group_4" & pid_candidate == "Dem"  
label var ISIS_lib_d "ISIS: liberal position"

gen guns_con_d = 0
replace guns_con_d = 1 if Guns_insert_aligned_rep_main == "I support “unrestricted” concealed carry gun laws. These laws do not require a permit to carry a concealed handgun." & group == "Group_1" 
replace guns_con_d = 1 if Guns_insert_aligned_rep_main == "I support “unrestricted” concealed carry gun laws. These laws do not require a permit to carry a concealed handgun." & group == "Group_1" 
replace guns_con_d = 1 if Guns_insert_aligned_rep_main == "I support “unrestricted” concealed carry gun laws. These laws do not require a permit to carry a concealed handgun." & group == "Group_2" & pid_candidate == "Rep" 
replace guns_con_d = 1 if Guns_insert_aligned_rep_main == "I support “unrestricted” concealed carry gun laws. These laws do not require a permit to carry a concealed handgun." & group == "Group_3" & pid_candidate == "Rep" 
replace guns_con_d = 1 if Guns_insert_aligned_rep_main == "I support “unrestricted” concealed carry gun laws. These laws do not require a permit to carry a concealed handgun." & group == "Group_4" & pid_candidate == "Rep"  
label var guns_con_d "Guns: conservative position"

gen taxes_con_d = 0
replace taxes_con_d = 1 if Taxes_insert_aligned_rep_main == "I support reducing the top marginal tax rate to 20%." & group == "Group_1" // good
replace taxes_con_d = 1 if Taxes_insert_aligned_rep_main == "I support reducing the top marginal tax rate to 20%." & group == "Group_2" & pid_candidate == "Rep"  
replace taxes_con_d = 1 if Taxes_insert_aligned_rep_main == "I support reducing the top marginal tax rate to 20%." & group == "Group_3" & pid_candidate == "Rep"  
replace taxes_con_d = 1 if Taxes_insert_aligned_rep_main == "I support reducing the top marginal tax rate to 20%." & group == "Group_4" & pid_candidate == "Rep"  
label var taxes_con_d "Taxes: conservative position"

gen SS_con_d = 0
replace SS_con_d = 1 if SS_insert_aligned_rep_main == "To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%." & group == "Group_1" // good
replace SS_con_d = 1 if SS_insert_aligned_rep_main == "To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%." & group == "Group_2" & pid_candidate == "Rep"  
replace SS_con_d = 1 if SS_insert_aligned_rep_main == "To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%." & group == "Group_3" & pid_candidate == "Rep"  
replace SS_con_d = 1 if SS_insert_aligned_rep_main == "To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%." & group == "Group_4" & pid_candidate == "Rep"  
label var SS_con_d "Social Security: conservative position"

gen Abort_con_d = 0
replace Abort_con_d = 1 if Abort_insert_aligned_rep_main == "I support making abortion legal only in cases where the mother’s life is in danger." & group == "Group_1" // not working
replace Abort_con_d = 1 if Abort_insert_aligned_rep_main == "I support making abortion legal only in cases where the mother’s life is in danger." & group == "Group_2" & pid_candidate == "Rep"  
replace Abort_con_d = 1 if Abort_insert_aligned_rep_main == "I support making abortion legal only in cases where the mother’s life is in danger." & group == "Group_3" & pid_candidate == "Rep"  
replace Abort_con_d = 1 if Abort_insert_aligned_rep_main == "I support making abortion legal only in cases where the mother’s life is in danger." & group == "Group_4" & pid_candidate == "Rep"  
label var Abort_con_d "Abortion: conservative position"

gen Welfare_con_d = 0
replace Welfare_con_d = 1 if Welfare_insert_aligned_rep_main == "I support reducing the lifetime cap from 5 years to 1 year." & group == "Group_1" //good
replace Welfare_con_d = 1 if Welfare_insert_aligned_rep_main == "I support reducing the lifetime cap from 5 years to 1 year." & group == "Group_2" & pid_candidate == "Rep"  
replace Welfare_con_d = 1 if Welfare_insert_aligned_rep_main == "I support reducing the lifetime cap from 5 years to 1 year." & group == "Group_3" & pid_candidate == "Rep"  
replace Welfare_con_d = 1 if Welfare_insert_aligned_rep_main == "I support reducing the lifetime cap from 5 years to 1 year." & group == "Group_4" & pid_candidate == "Rep"  
label var Welfare_con_d "Welfare: conservative position"

gen ISIS_con_d = 0
replace ISIS_con_d = 1 if ISIS_insert_aligned_rep_main == "I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq." & group == "Group_1" // good
replace ISIS_con_d = 1 if ISIS_insert_aligned_rep_main == "I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq." & group == "Group_2" & pid_candidate == "Rep"  
replace ISIS_con_d = 1 if ISIS_insert_aligned_rep_main == "I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq." & group == "Group_3" & pid_candidate == "Rep"  
replace ISIS_con_d = 1 if ISIS_insert_aligned_rep_main == "I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq." & group == "Group_4" & pid_candidate == "Rep"  
label var ISIS_con_d "ISIS: conservative position"

* Treatment indicators
gen T_Extreme_treatment = 0
replace T_Extreme_treatment = 1 if group == "Group_2"
label var T_Extreme_treatment "Extreme Candidate"

gen T_Inconsistent_treatment = 0
replace T_Inconsistent_treatment = 1 if group == "Group_3"
label var T_Inconsistent_treatment "Unusual Candidate"

gen T_Bipartisan_treatment = 0
replace T_Bipartisan_treatment = 1 if group == "Group_4"
label var T_Bipartisan_treatment "Bipartisan Candidate"

gen T_Aligned_treatment = 0
replace T_Aligned_treatment = 1 if group == "Group_1"
label var T_Aligned_treatment "Aligned treatment"

gen T_Dem_cand = 0
replace T_Dem_cand = 1 if pid_candidate == "Dem"
label var T_Dem_cand "Shown Democratic candidate"

* These are covariates
gen dem_d = 0
replace dem_d = 1 if pid3 == -1

gen rep_d = 0
replace rep_d = 1 if pid3 == 1

gen ind_d = 0
replace ind_d = 1 if pid3 == 0
label var ind_d "Pure Independents"

gen dem_lean = 0
replace dem_lean = 1 if pid7 == -1
label var dem_lean "Leaning Democrat"

gen dem_weak = 0
replace dem_weak = 1 if pid7 == -2
label var dem_weak "Weak Democrat"

gen rep_lean = 0
replace rep_lean = 1 if pid7 == 1
label var rep_lean "Leaning Republican"

gen rep_weak = 0
replace rep_weak = 1 if pid7 == 2
label var rep_weak "Weak Republican"

gen rep_strong = 0
replace rep_strong = 1 if pid7 == 3
label var rep_strong "Strong Republican"

gen strong_partisan = 0
replace strong_partisan = 1 if pid7 == -3 | pid7 == 3
label var strong_partisan "Strong Partisans"

gen weak_partisan = 0
replace weak_partisan = 1 if pid7 == -2 | pid7 == 2
label var weak_partisan "Weak Partisans"

gen lean_partisan = 0
replace lean_partisan = 1 if pid7 == -1 | pid7 == 1
label var lean_partisan "Lean Partisans"

// dummy vars for marks of competences. for regression, manager with 10 employees is excluded category

gen manager_10_sl = 0
replace manager_10_sl = 1 if marks_of_competency_main == "a manager of a company with 10 employees and was a member of the state legislature."
label var manager_10_sl "10 Employees, State Legislature"

gen manager_10_cc = 0
replace manager_10_cc = 1 if marks_of_competency_main == "a manager of a company with 10 employees and was a member of the city council."
label var manager_10_cc "10 Employees, City Council"

gen manager_100 = 0
replace manager_100 = 1 if marks_of_competency_main == "a manager of a company with 100 employees."
label var manager_100 "100 Employees"

gen manager_100_sl = 0
replace manager_100_sl = 1 if marks_of_competency_main == "a manager of a company with 100 employees and was a member of the state legislature."
label var manager_100_sl "100 Employees, State Legislature"

gen manager_100_cc = 0
replace manager_100_cc = 1 if marks_of_competency_main == "a manager of a company with 100 employees and was a member of the city council."
label var manager_100_cc "100 Employees, City Council"

// note spelling error on randomized insert
gen manager_1000 = 0
replace manager_1000 = 1 if marks_of_competency_main == "a manger of a company with 1000 employees."
label var manager_1000 "1000 Employees"

gen manager_1000_sl = 0
replace manager_1000_sl = 1 if marks_of_competency_main == "a manager of a company with 1000 employees and was a member of the state legislature."
label var manager_1000_sl "1000 Employees, State Legislature"

gen manager_1000_cc = 0
replace manager_1000_cc = 1 if marks_of_competency_main == "a manager of a company with 1000 employees and was a member of the city council."
label var manager_1000_cc "1000 Employees, City Council"


//// INDIVIDUAL LEVEL CONTROL VARIABLES
// EDUCATION LEVEL
tab education
gen HSorLess = 0
replace HSorLess = 1 if education == 1 | education==2
gen SomeColl = 0
replace SomeColl = 1 if education == 3 | education==4
gen College = 0
replace College = 1 if education == 5
gen PostGrad = 0
replace PostGrad = 1 if education == 6


// RACE AND ETHNICITY
tab race // black and hispanic indicators already exist

gen other = 0
replace other = 1 if race == 4 | race==5 | race==6 | race==7 | race==8



// AGE
tab age
gen a18_29 = 0
replace a18_29 = 1 if age < 30
gen a30_39 = 0
replace a30_39 = 1 if age > 29 & age < 40
gen a40_49 = 0
replace a40_49 = 1 if age > 39 & age < 50
gen a50_59 = 0
replace a50_59 = 1 if age > 49 & age < 60
gen a60_69 = 0
replace a60_69 = 1 if age > 59 & age < 70
gen a70_79 = 0
replace a70_79 = 1 if age > 69 & age < 80
gen a80plus = 0
replace a80plus = 1 if age > 79


// INCOME -> MAKE BINS MATCH DONOR BINS
tab income
gen less30k = 0
replace less30k = 1 if income < 6
gen i30k_69k = 0
replace i30k_69k = 1 if income > 5 & income < 10
gen i70k_100k = 0
replace i70k_100k = 1 if income > 9 & income < 12
gen i100k_200k = 0
replace i100k_200k = 1 if income > 11 & income < 15
gen i200k_250k = 0
replace i200k_250k = 1 if income ==15
gen i250kplus = 0
replace i250kplus = 1 if income ==16




/// recode outcome measure -> overall competency
recode main_competency (1=0) (2=.25) (3=.5) (4=.75) (5=1), gen(compet)
tab main_competency compet








//////////////////////////////////////////// 
// OUTREG TABLES FOR EACH OUTCOME MEASURE //
////////////////////////////////////////////


* Sample lincom two variables code
* local t1 : variable label `var1'
* local t2 : variable label `var2'
* qui lincom  `var1' -`var2'
* local fx = `r(estimate)'
* local tstat = abs(`r(estimate)'/`r(se)')
* local pvalue=ttail(`r(df)',`tstat')*2
* and 95% cI of lincom
* local  upperci= r(estimate) + invttail(r(df),0.025)*r(se)
* local lowerci = r(estimate) + invttail(r(df),0.975)*r(se)




// all partisans -> include sample size, lincom, and aligned mean
reg compet T_Extreme_treatment T_Bipartisan_treatment T_Inconsistent_treatment T_Dem_cand  ///
strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts /// 
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
if pid7 != 0




/* The following block of code makes the MFX plot */

/* Make all changes here: */

/* Graph Name for Export */
local graphfilename = "Figure2_a"

/* Define Table Title Here */
local titletext = "Partisans Evaluating Their Own Party's Candidate"

/* Define note and caption text here. Note comes first. */
local notetext = "n=1,742. Plotted quantities are change in competency relative to the aligned candidate with 95% CI."
local captiontext = "Lincom estimates from regression with controls. See Appendix for full results."

/* STARTING HERE, THIS BLOCK SHOULD REMAIN FIXED */

local outcomelab : variable label `e(depvar)'

gen _linctr=.
gen _lincomest=. 
gen _lincomtext=""
gen _lowerci=. 
gen _upperci=. 

local ctr=0

local tvar="T_Extreme_treatment"
include 00_sub_doonevarlincomforgraph.do
local tvar="T_Bipartisan_treatment"
include 00_sub_doonevarlincomforgraph.do 
local tvar="T_Inconsistent_treatment"
include 00_sub_doonevarlincomforgraph.do 


labmask _linctr, values(_lincomtext)

qui summ _linctr
local ctrmin=r(min)
local ctrmax=r(max)
if `ctrmin'>0 {
	local ctrmin=0
	}
if `ctrmax'<0 {
	local ctrmax=0 
	}
local rangemin=r(min)-.50
local rangemax=r(max)+.50
qui summ _upperci
local ymax=max(.01,r(max))
qui summ _lowerci
local ymin=min(.01,r(min))

twoway (scatter _lincomest _linctr, mcolor(black) msymbol(circle)) (rcap _lowerci _upperci _linctr, lcolor(black)), ytitle("Change in Competency Relative to Aligned Candidate", size(small) margin(right)) yline(0, lpattern(dash) lcolor(black))  yscale(range(`ymin' `ymax')) xscale(range(`rangemin' `rangemax')) xtitle("") ylabel(0 "0%" -.05 "-5%"  -.1 "-10%" -.15 "-15%" -.2 "-20%") xlabel(`ctrmin'(1)`ctrmax', labels labsize(small) valuelabel) xmtick(none) title("`titletext'", size(small)) note("`notetext'", size(small) color(black) span margin(top)) caption("`captiontext'", size(small) color(black) span) legend(off) scheme(s1mono) name("`graphfilename'", replace)
graph export "`graphfilename'.pdf", as(pdf) replace

capture drop _linctr _lincomest _lincomtext _lowerci _upperci
capture label drop _linctr

/* END FIXED BLOCK */




// Pure Independents Only -> include sample size, lincom, and aligned mean
reg compet T_Extreme_treatment T_Bipartisan_treatment T_Inconsistent_treatment T_Dem_cand  ///
strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts /// 
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
if pid7 == 0




/* The following block of code makes the MFX plot */

/* Make all changes here: */

/* Graph Name for Export */
local graphfilename = "Figure2_b"

/* Define Table Title Here */
local titletext = "Pure Independents Evaluating a Randomly Selected Democratic or Republican Candidate"

/* Define note and caption text here. Note comes first. */
local notetext = "n=317. Plotted quantities are change in competency relative to the aligned candidate with 95% CI."
local captiontext = "Lincom estimates from regression with controls. See Appendix for full results."

/* STARTING HERE, THIS BLOCK SHOULD REMAIN FIXED */

local outcomelab : variable label `e(depvar)'

gen _linctr=.
gen _lincomest=. 
gen _lincomtext=""
gen _lowerci=. 
gen _upperci=. 

local ctr=0

local tvar="T_Extreme_treatment"
include 00_sub_doonevarlincomforgraph.do
local tvar="T_Bipartisan_treatment"
include 00_sub_doonevarlincomforgraph.do 
local tvar="T_Inconsistent_treatment"
include 00_sub_doonevarlincomforgraph.do 


labmask _linctr, values(_lincomtext)

qui summ _linctr
local ctrmin=r(min)
local ctrmax=r(max)
if `ctrmin'>0 {
	local ctrmin=0
	}
if `ctrmax'<0 {
	local ctrmax=0 
	}
local rangemin=r(min)-.50
local rangemax=r(max)+.50
qui summ _upperci
local ymax=max(.01,r(max))
qui summ _lowerci
local ymin=min(.01,r(min))

twoway (scatter _lincomest _linctr, mcolor(black) msymbol(circle)) (rcap _lowerci _upperci _linctr, lcolor(black)), ytitle("Change in Competency Relative to Aligned Candidate", size(small) margin(right)) yline(0, lpattern(dash) lcolor(black))  yscale(range(`ymin' `ymax')) xscale(range(`rangemin' `rangemax')) xtitle("") ylabel(0 "0%" -.05 "-5%"  -.1 "-10%" -.15 "-15%" -.2 "-20%") xlabel(`ctrmin'(1)`ctrmax', labels labsize(small) valuelabel) xmtick(none) title("`titletext'", size(small)) note("`notetext'", size(small) color(black) span margin(top)) caption("`captiontext'", size(small) color(black) span) legend(off) scheme(s1mono) name("`graphfilename'", replace)
graph export "`graphfilename'.pdf", as(pdf) replace

capture drop _linctr _lincomest _lincomtext _lowerci _upperci
capture label drop _linctr

/* END FIXED BLOCK */



//// OUTSUM TABLES WITH SAME MODEL FOR APPENDIX

reg compet T_Extreme_treatment T_Bipartisan_treatment T_Inconsistent_treatment T_Dem_cand  ///
strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts /// 
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
if pid7 != 0
outreg2 using TableA6_Figure2RegressionOutput.out, replace ctitle(All Partisans) bracket ///

summ compet if T_Aligned_treatment ==1 & pid7 != 0



reg compet T_Extreme_treatment T_Bipartisan_treatment T_Inconsistent_treatment T_Dem_cand  ///
strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts /// 
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
if pid7 == 0
outreg2 using TableA6_Figure2RegressionOutput.out, append ctitle(Pure Independents) bracket ///

summ compet if T_Aligned_treatment ==1 & pid7 == 0






