
// Figure 4 Leadership Ability Vignette
// regresses treatment variables and control for issue position, issue strength, and self-placed party ID on outcome variables

// NOTE: Need to run "Figure 2 Overall Competency Vignette.do" first!

//////////////////////////////////////////// 
// OUTREG TABLES FOR EACH OUTCOME MEASURE //
////////////////////////////////////////////


* Sample lincom two variables code
* local t1 : variable label `var1'
* local t2 : variable label `var2'
* qui lincom  `var1' -`var2'
* local fx = `r(estimate)'
* local tstat = abs(`r(estimate)'/`r(se)')
* local pvalue=ttail(`r(df)',`tstat')*2
* and 95% cI of lincom
* local  upperci= r(estimate) + invttail(r(df),0.025)*r(se)
* local lowerci = r(estimate) + invttail(r(df),0.975)*r(se)

////////////////////////////////////////////////////
// feeling thermometer with partisans broken out //
////////////////////////////////////////////////////

reg Leadership_Characteristics_index T_Extreme_treatment T_Inconsistent_treatment T_Bipartisan_treatment if pid7 !=0


//label var main_ideology_mod "Ideology from Moderate (0-2)"

// all partisans -> include sample size, lincom, and aligned mean
reg Leadership_Characteristics_index T_Extreme_treatment T_Inconsistent_treatment T_Bipartisan_treatment T_Dem_cand Abortion_inserts Guns_inserts ISIS_inserts SocialSecurity_inserts ///
Welfare_inserts guns_lib_d taxes_lib_d SS_lib_d Abort_lib_d Welfare_lib_d ISIS_lib_d guns_con_d taxes_con_d SS_con_d Abort_con_d Welfare_con_d ISIS_con_d ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus if pid7 != 0


/* Make all changes here: */

/* Graph Name for Export */
local graphfilename = "Figure4_a"

/* Define Table Title Here */
local titletext = "Partisans Evaluating Their Own Party's Candidate"

/* Define note and caption text here. Note comes first. */
local notetext = "n=1,735. Plotted quantities are change in valence evaluations relative to the aligned candidate with 95% CI."
local captiontext = "Lincom estimates from regression with controls. See Appendix for full results."

/* STARTING HERE, THIS BLOCK SHOULD REMAIN FIXED */

local outcomelab : variable label `e(depvar)'

gen _linctr=.
gen _lincomest=. 
gen _lincomtext=""
gen _lowerci=. 
gen _upperci=. 

local ctr=0
local tvar="T_Extreme_treatment"
include 00_sub_doonevarlincomforgraph.do
local tvar="T_Bipartisan_treatment"
include 00_sub_doonevarlincomforgraph.do 
local tvar="T_Inconsistent_treatment"
include 00_sub_doonevarlincomforgraph.do 

labmask _linctr, values(_lincomtext)

qui summ _linctr
local ctrmin=r(min)
local ctrmax=r(max)
if `ctrmin'>0 {
	local ctrmin=0
	}
if `ctrmax'<0 {
	local ctrmax=0 
	}
local rangemin=r(min)-.50
local rangemax=r(max)+.50
qui summ _upperci
local ymax=max(.01,r(max))
qui summ _lowerci
local ymin=min(.01,r(min))

twoway (scatter _lincomest _linctr, mcolor(black) msymbol(circle)) (rcap _lowerci _upperci _linctr, lcolor(black)), ytitle("Change in Leadership Ability Relative to Aligned Candidate", size(small) margin(right)) yline(0, lpattern(dash) lcolor(black))  yscale(range(`ymin' `ymax')) xscale(range(`rangemin' `rangemax')) xtitle("") ylabel(0 "0" -.05 "-.05"  -.1 "-.10" -.15 "-.15" -.2 "-.20") xlabel(`ctrmin'(1)`ctrmax', labels labsize(small) valuelabel) xmtick(none) title("`titletext'", size(small)) note("`notetext'", size(small) color(black) span margin(top)) caption("`captiontext'", size(small) color(black) span) legend(off) scheme(s1mono) name("`graphfilename'", replace)
graph export "`graphfilename'.pdf", as(pdf) replace

capture drop _linctr _lincomest _lincomtext _lowerci _upperci
capture label drop _linctr

/* END FIXED BLOCK */
/* End MFX plot block */

lincom T_Extreme_treatment - T_Inconsistent_treatment
local lincom1=r(estimate)
local tstat1= abs(`r(estimate)'/`r(se)')
local pvalue1=ttail(`r(df)',`tstat1')*2
lincom T_Extreme_treatment - T_Bipartisan_treatment
local lincom2=r(estimate)
local tstat2= abs(`r(estimate)'/`r(se)')
local pvalue2=ttail(`r(df)',`tstat2')*2
lincom T_Bipartisan_treatment - T_Inconsistent_treatment
local lincom3=r(estimate)
local tstat3= abs(`r(estimate)'/`r(se)')
local pvalue3=ttail(`r(df)',`tstat3')*2
summ main_ideo_certainty if e(sample) & group == "Group_1"
local aligned=r(mean)
outreg2 using ideo_cert.out, replace ctitle(All Partisans) bracket ///
addstat("Aligned Mean", `aligned', "Linear Combination of (Extreme - Inconsistent)", `lincom1', "P-value for Linear Combination", `pvalue1', "Linear Combination of (Extreme - Bi-Partisan)", `lincom2', "P-value for Linear Combination", `pvalue2', "Linear Combination of (Bi-Partisan - Inconsistent)", `lincom3', "P-value for Linear Combination", `pvalue3') label ///
addnote("All dependent variables are dummy such that 1=yes and 0 = no. Excluded categories for both regressions: Aligned treatment group, guns issue area displayed, and Republican candidate shown. Partisans only.")





// all partisans -> include sample size, lincom, and aligned mean
reg Leadership_Characteristics_index T_Extreme_treatment T_Bipartisan_treatment T_Inconsistent_treatment T_Dem_cand ///
strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts /// 
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
if pid7 != 0
outreg2 using Table_A8_Figure4RegressionOutput.out, replace ctitle(All Partisans) bracket ///

summ Leadership_Characteristics_index if T_Aligned_treatment ==1 & pid7 != 0




//////////////////////////////////////////// 
// INDEPENDENTS ONLY //
////////////////////////////////////////////


* Sample lincom two variables code
* local t1 : variable label `var1'
* local t2 : variable label `var2'
* qui lincom  `var1' -`var2'
* local fx = `r(estimate)'
* local tstat = abs(`r(estimate)'/`r(se)')
* local pvalue=ttail(`r(df)',`tstat')*2
* and 95% cI of lincom
* local  upperci= r(estimate) + invttail(r(df),0.025)*r(se)
* local lowerci = r(estimate) + invttail(r(df),0.975)*r(se)

////////////////////////////////////////////////////
// feeling thermometer with partisans broken out //
////////////////////////////////////////////////////

//label var main_ideology_mod "Ideology from Moderate (0-2)"

// pure independents -> include sample size, lincom, and aligned mean
reg Leadership_Characteristics_index T_Extreme_treatment T_Inconsistent_treatment T_Bipartisan_treatment T_Dem_cand Abortion_inserts Guns_inserts ISIS_inserts SocialSecurity_inserts ///
Welfare_inserts guns_lib_d taxes_lib_d SS_lib_d Abort_lib_d Welfare_lib_d ISIS_lib_d guns_con_d taxes_con_d SS_con_d Abort_con_d Welfare_con_d ISIS_con_d ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc  ///
strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus if pid7 == 0

/* The following block of code makes the MFX plot */

/* Make all changes here: */

/* Graph Name for Export */
local graphfilename = "Figure4_b"

/* Define Table Title Here */
local titletext = "Pure Independents Evaluating a Randomly Selected Democratic or Republican Candidate"

/* Define note and caption text here. Note comes first. */
local notetext = "n=317. Plotted quantities are change in valence evaluations relative to the aligned candidate with 95% CI."
local captiontext = "Lincom estimates from regression with controls. See Appendix for full results."

/* STARTING HERE, THIS BLOCK SHOULD REMAIN FIXED */

local outcomelab : variable label `e(depvar)'

gen _linctr=.
gen _lincomest=. 
gen _lincomtext=""
gen _lowerci=. 
gen _upperci=. 

local ctr=0
local tvar="T_Extreme_treatment"
include 00_sub_doonevarlincomforgraph.do
local tvar="T_Bipartisan_treatment"
include 00_sub_doonevarlincomforgraph.do 
local tvar="T_Inconsistent_treatment"
include 00_sub_doonevarlincomforgraph.do 

labmask _linctr, values(_lincomtext)

qui summ _linctr
local ctrmin=r(min)
local ctrmax=r(max)
if `ctrmin'>0 {
	local ctrmin=0
	}
if `ctrmax'<0 {
	local ctrmax=0 
	}
local rangemin=r(min)-.50
local rangemax=r(max)+.50
qui summ _upperci
local ymax=max(.01,r(max))
qui summ _lowerci
local ymin=min(.01,r(min))

twoway (scatter _lincomest _linctr, mcolor(black) msymbol(circle)) (rcap _lowerci _upperci _linctr, lcolor(black)), ytitle("Change in Leadership Ability Relative to Aligned Candidate", size(small) margin(right)) yline(0, lpattern(dash) lcolor(black))  yscale(range(`ymin' `ymax')) ylabel(0 "0" -.05 "-.05"  -.1 "-.10" -.15 "-.15" -.20 "-.20") xscale(range(`rangemin' `rangemax')) xtitle("") xlabel(`ctrmin'(1)`ctrmax', labels labsize(small) valuelabel) xmtick(none) title("`titletext'", size(small)) note("`notetext'", size(small) color(black) span margin(top)) caption("`captiontext'", size(small) color(black) span) legend(off) scheme(s1mono) name("`graphfilename'", replace)
graph export "`graphfilename'.pdf", as(pdf) replace

capture drop _linctr _lincomest _lincomtext _lowerci _upperci
capture label drop _linctr

/* END FIXED BLOCK */
/* End MFX plot block */

lincom T_Extreme_treatment - T_Inconsistent_treatment
local lincom1=r(estimate)
local tstat1= abs(`r(estimate)'/`r(se)')
local pvalue1=ttail(`r(df)',`tstat1')*2
lincom T_Extreme_treatment - T_Bipartisan_treatment
local lincom2=r(estimate)
local tstat2= abs(`r(estimate)'/`r(se)')
local pvalue2=ttail(`r(df)',`tstat2')*2
lincom T_Bipartisan_treatment - T_Inconsistent_treatment
local lincom3=r(estimate)
local tstat3= abs(`r(estimate)'/`r(se)')
local pvalue3=ttail(`r(df)',`tstat3')*2
summ main_ideo_certainty if e(sample) & group == "Group_1"
local aligned=r(mean)
outreg2 using ideo_cert.out, replace ctitle(All Partisans) bracket ///
addstat("Aligned Mean", `aligned', "Linear Combination of (Extreme - Inconsistent)", `lincom1', "P-value for Linear Combination", `pvalue1', "Linear Combination of (Extreme - Bi-Partisan)", `lincom2', "P-value for Linear Combination", `pvalue2', "Linear Combination of (Bi-Partisan - Inconsistent)", `lincom3', "P-value for Linear Combination", `pvalue3') label ///
addnote("All dependent variables are dummy such that 1=yes and 0 = no. Excluded categories for both regressions: Aligned treatment group, guns issue area displayed, and Republican candidate shown. Partisans only.")




// pure ind -> include sample size, lincom, and aligned mean
reg Leadership_Characteristics_index T_Extreme_treatment T_Bipartisan_treatment T_Inconsistent_treatment T_Dem_cand ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts /// 
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
if pid7 == 0
outreg2 using Table_A8_Figure4RegressionOutput.out, append ctitle(Pure Independents) bracket ///

summ Leadership_Characteristics_index if T_Aligned_treatment ==1 & pid7 == 0




















